@@ -1,6 +1,9 @@
 package filter
 
-import "github.com/gruntwork-io/terragrunt/internal/component"
+import (
+	"github.com/gruntwork-io/terragrunt/internal/component"
+	"github.com/gruntwork-io/terragrunt/pkg/log"
+)
 
 // Filter represents a parsed filter query that can be evaluated against discovered configs.
 type Filter struct {
@@ -33,8 +36,9 @@ func Parse(filterString, workingDir string) (*Filter, error) {
 }
 
 // Evaluate applies the filter to a list of components and returns the filtered result.
-func (f *Filter) Evaluate(components component.Components) (component.Components, error) {
-	return Evaluate(f.expr, components)
+// If logger is provided, it will be used for logging warnings during evaluation.
+func (f *Filter) Evaluate(l log.Logger, components component.Components) (component.Components, error) {
+	return Evaluate(l, f.expr, components)
 }
 
 // Expression returns the parsed AST expression.
@@ -45,11 +49,11 @@ func (f *Filter) Expression() Expression {
 
 // Apply is a convenience function that parses and evaluates a filter in one step.
 // It's equivalent to calling Parse followed by Evaluate.
-func Apply(filterString, workingDir string, components component.Components) (component.Components, error) {
+func Apply(l log.Logger, filterString, workingDir string, components component.Components) (component.Components, error) {
 	filter, err := Parse(filterString, workingDir)
 	if err != nil {
 		return nil, err
 	}
 
-	return filter.Evaluate(components)
+	return filter.Evaluate(l, components)
 }
